@@ -63,26 +63,27 @@ var NAVTREEINDEX =
 [
 "alloc_8h.html",
 "group__pw__client.html#gaffa5b807a9674495aa5c14a68d5fd88c",
-"group__pw__global.html#gaf901fcdcb9d2059370fdd9d6ad188c3f",
-"group__pw__keys.html#gaae4d17260ca60c2ab5e2c8d32b989d67",
-"group__pw__node.html#ga91a6a1a257b75f8a6fd5eb6755447a59",
-"group__pw__session__manager.html#ga3e4945a8ef7615d8e4b574209890a68b",
-"group__pwtest.html#ga60aaaf4bca029a7cd77d9e2328cc33b0",
-"group__spa__dbus.html#ga86263eb7e15c01e44c67b4b92c777a45",
-"group__spa__keys.html#ga397212748e5208c2727994b89ab56b04",
-"group__spa__node.html#ga4057156d1eaf9f13cab72a187735ad65",
-"group__spa__param.html#ga7f188485cf47ffb05c8f6be407448f2c",
-"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbca4c1b239852626671b53906f9d9b89e42",
-"group__spa__param.html#ggab89b8affc8ad458b2cc10dd9e8423fe7acb6b47253078f2060df6af90fdedaf27",
-"group__spa__pod.html#ga1d4549904c233c319e9a6222d7781948",
-"group__spa__pod.html#gga38ee9b093a1a766cfc3d96db7c28067fab83a47468dd6f92b64b943c4974cf799",
-"hook_8h.html",
-"page_spa_plugins.html",
-"structpw__device.html",
-"structpw__memmap.html",
-"structspa__audio__info.html#a07b9f000b469ff8389b93290a5a06b2b",
-"structspa__io__segment.html#ac4988f1d377a80a859eb45771f3317fb",
-"structspa__pod__object.html#a48beaa7536f4c339aac23729c42a64f3"
+"group__pw__global.html#gae35b9eb5ebbdead2e5a79845d5fa2031",
+"group__pw__keys.html#gaa2b0c7062965986d9d8dbadf553eb6ba",
+"group__pw__node.html#ga5437fe007ac346f48f0f63fec8ca8b40",
+"group__pw__session__manager.html#ga2e7a34daf8b8253ed9bffd78cdca8e7f",
+"group__pwtest.html#ga2c915fce91d56c38b5f5a3c4e58c43b2",
+"group__spa__cpu.html#gaeaa02c7399c9c2e26501e6e220dd9910",
+"group__spa__json.html#ga9e5319ac5846fb6219a973e0cfa46786",
+"group__spa__names.html#gaf8c5034276b9d90ecb0c2581de0ada62",
+"group__spa__param.html#ga4c6b9dbf27cb5f8e564c2de697bfc175",
+"group__spa__param.html#gga339d759aafadca6ef623f32ce7e65be0a9c4a4f508012ae916946d2bc8f62c736",
+"group__spa__param.html#ggaaa66f9e8b1228f1ef1f2630d8d9c5ab5a12a939e254137ec3137f3600f7f8e5ee",
+"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43eaec4287ed05c95eba5c69a1c515e76f80",
+"group__spa__pod.html#gabdf6e06a4b3861a11841166dff9d04c3",
+"group__spa__utils__defs.html#ga48e64fde9ece326caf683b04597614a5",
+"page_objects_design.html#autotoc_md75",
+"structpw__client__node__events.html",
+"structpw__impl__module__events.html#a75c9588d21472e8d610b813bdd9a419e",
+"structpw__session__info.html#a00aaf0720fd58ae285a1fe122ab0fb93",
+"structspa__dict.html#a3b3b78bfe5fffe13a10720bb7099c399",
+"structspa__meta__header.html#aae54e5badad1945c2a49d64842df5b1f",
+"structspa__thread.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
