@@ -1,5 +1,14 @@
 var NAVTREEINDEX7 =
 {
+"group__spa__cpu.html#gaeaa02c7399c9c2e26501e6e220dd9910":[10,8,9,0,40],
+"group__spa__cpu.html#gaefc0478de60eb509f0c7b571d1a58622":[10,8,9,0,51],
+"group__spa__cpu.html#gaf0b85f94092b16c66534cd3206c30870":[10,8,9,0,55],
+"group__spa__cpu.html#gafd7cd22cbf0138875264c22ea79eef16":[10,8,9,0,56],
+"group__spa__dbus.html":[10,8,9,1],
+"group__spa__dbus.html#ga38d6b3e2b9367e194e5ed4a7adbe9471":[10,8,9,1,13],
+"group__spa__dbus.html#ga39128520ce2167eb64279fc23e617fa0":[10,8,9,1,18],
+"group__spa__dbus.html#ga3b4641d430f6892c79f6a02284349dbf":[10,8,9,1,10],
+"group__spa__dbus.html#ga8015339211635f3bcf91ff52a9953678":[10,8,9,1,5],
 "group__spa__dbus.html#ga86263eb7e15c01e44c67b4b92c777a45":[10,8,9,1,6],
 "group__spa__dbus.html#ga9c9264eb38a39811f9a1103bef5d1d99":[10,8,9,1,17],
 "group__spa__dbus.html#gaa1bb9052d868e1185afd82668582d740":[10,8,9,1,9],
@@ -15,23 +24,39 @@ var NAVTREEINDEX7 =
 "group__spa__dbus.html#gga39128520ce2167eb64279fc23e617fa0a4645a44a9d5954b882e7a3c23672fed8":[10,8,9,1,18,2],
 "group__spa__dbus.html#gga39128520ce2167eb64279fc23e617fa0a5fdca2872c84184d6a5ca0701726d229":[10,8,9,1,18,1],
 "group__spa__debug.html":[10,8,3],
-"group__spa__debug.html#ga065cb6c3687ae83e7e2ca50296f78140":[10,8,3,9],
-"group__spa__debug.html#ga0c0aff43e13b4501952801fa3be7b1b7":[10,8,3,13],
-"group__spa__debug.html#ga17e8a8e1fb9113f5add80d0b1cfe9602":[10,8,3,11],
-"group__spa__debug.html#ga26f0007da5add3060d00672939508d55":[10,8,3,15],
-"group__spa__debug.html#ga38094276cb4dfb2190710683f4edc139":[10,8,3,10],
-"group__spa__debug.html#ga3e5050c5f3596911cd4cf32049eae71f":[10,8,3,8],
-"group__spa__debug.html#ga43407166bdc04c3822b66257581fec18":[10,8,3,22],
-"group__spa__debug.html#ga43da221712a4457ff34457555d39b214":[10,8,3,17],
-"group__spa__debug.html#ga4b2e0edb1afe21a398be311ab6bde5b9":[10,8,3,18],
-"group__spa__debug.html#ga8907dcd66c24ffc68f2d328111428936":[10,8,3,20],
-"group__spa__debug.html#ga894c39341a4e23d74318af04868a71df":[10,8,3,19],
-"group__spa__debug.html#ga8ad92675783ea166fc2ea34dad54b75a":[10,8,3,21],
-"group__spa__debug.html#gaa00cdef782319e1a9ae738ffb9422506":[10,8,3,16],
-"group__spa__debug.html#gac0431ebc7981b41690e6356925bcc954":[10,8,3,23],
-"group__spa__debug.html#gac6f960544afa686154bfebae8c42406b":[10,8,3,24],
-"group__spa__debug.html#gae0fd7bbdbaad907ad5b923053f888dca":[10,8,3,14],
-"group__spa__debug.html#gaeec0bfa08b41f3002b60ed2e997cabbe":[10,8,3,12],
+"group__spa__debug.html#ga0c0aff43e13b4501952801fa3be7b1b7":[10,8,3,27],
+"group__spa__debug.html#ga16f96238e59068d1a7637230cb667412":[10,8,3,17],
+"group__spa__debug.html#ga17e8a8e1fb9113f5add80d0b1cfe9602":[10,8,3,23],
+"group__spa__debug.html#ga20c14faa56c9f91aaccbc7b78bee4d75":[10,8,3,11],
+"group__spa__debug.html#ga26f0007da5add3060d00672939508d55":[10,8,3,32],
+"group__spa__debug.html#ga33cb832be355e3f0a39d547fbd005735":[10,8,3,14],
+"group__spa__debug.html#ga38094276cb4dfb2190710683f4edc139":[10,8,3,21],
+"group__spa__debug.html#ga3e6c9fbc3e47f47500bf59145a8baadb":[10,8,3,34],
+"group__spa__debug.html#ga3f8d824bf3268bbe885154db6a3a5215":[10,8,3,13],
+"group__spa__debug.html#ga43407166bdc04c3822b66257581fec18":[10,8,3,41],
+"group__spa__debug.html#ga43da221712a4457ff34457555d39b214":[10,8,3,36],
+"group__spa__debug.html#ga4b2e0edb1afe21a398be311ab6bde5b9":[10,8,3,37],
+"group__spa__debug.html#ga5eb6d7ec8b97e55331c9297a581800a5":[10,8,3,26],
+"group__spa__debug.html#ga6b44755735f4fdcce858fa6f97594b65":[10,8,3,22],
+"group__spa__debug.html#ga6f983769067496ffae1b55d9a457384f":[10,8,3,18],
+"group__spa__debug.html#ga8907dcd66c24ffc68f2d328111428936":[10,8,3,39],
+"group__spa__debug.html#ga894c39341a4e23d74318af04868a71df":[10,8,3,38],
+"group__spa__debug.html#ga8ad92675783ea166fc2ea34dad54b75a":[10,8,3,40],
+"group__spa__debug.html#ga8bb3edd099bef82423cee5eff879c339":[10,8,3,28],
+"group__spa__debug.html#ga95e569a17a18eab8f646974d0b2cc136":[10,8,3,20],
+"group__spa__debug.html#ga9d07bf77d70f8ccc9b1254e46a22a243":[10,8,3,16],
+"group__spa__debug.html#ga9df460de860ee08b42581d9846960494":[10,8,3,12],
+"group__spa__debug.html#gaa00cdef782319e1a9ae738ffb9422506":[10,8,3,35],
+"group__spa__debug.html#gac0431ebc7981b41690e6356925bcc954":[10,8,3,42],
+"group__spa__debug.html#gac394fa61f7506be415fd8c0b6e422c6a":[10,8,3,33],
+"group__spa__debug.html#gac6f960544afa686154bfebae8c42406b":[10,8,3,43],
+"group__spa__debug.html#gad9d0f508b3ec1caafca4e66dc51cd5b5":[10,8,3,15],
+"group__spa__debug.html#gae0fd7bbdbaad907ad5b923053f888dca":[10,8,3,30],
+"group__spa__debug.html#gaeec0bfa08b41f3002b60ed2e997cabbe":[10,8,3,25],
+"group__spa__debug.html#gaef7cbb7d8a18d32656a9149cd4fdfd6d":[10,8,3,24],
+"group__spa__debug.html#gaf6cbda715cf394fce2121122f2f3b9ed":[10,8,3,19],
+"group__spa__debug.html#gafaccba3f44098f680e755ad34b421de0":[10,8,3,29],
+"group__spa__debug.html#gafb77a961ae0c0be0034f2a1b4f264ee9":[10,8,3,31],
 "group__spa__device.html":[10,8,4],
 "group__spa__device.html#ga0176aee6eac7ee89895ab4f4069afa41":[10,8,4,44],
 "group__spa__device.html#ga020999d4feb921cd73b094b826a99d32":[10,8,4,61],
@@ -224,30 +249,5 @@ var NAVTREEINDEX7 =
 "group__spa__json.html#ga7c080249c08879b0576e5225a67fde7e":[10,8,8,6,19],
 "group__spa__json.html#ga8e5fa24c312810edffc063169e55497d":[10,8,8,6,13],
 "group__spa__json.html#ga910d92b40deefb1451ddcdee9b96c243":[10,8,8,6,27],
-"group__spa__json.html#ga9110761cf050dd015410b949edd24350":[10,8,8,6,15],
-"group__spa__json.html#ga9e5319ac5846fb6219a973e0cfa46786":[10,8,8,6,3],
-"group__spa__json.html#gab03680b46f934bdc18755d2156077cf1":[10,8,8,6,33],
-"group__spa__json.html#gabc34f55fde305ab5ff6a28d34a642170":[10,8,8,6,20],
-"group__spa__json.html#gac6aa5f68834748dc6790cf5dd2ac9401":[10,8,8,6,7],
-"group__spa__json.html#gacc0420e669d2d9ab67bf711a63373026":[10,8,8,6,9],
-"group__spa__json.html#gacda21b833e3e2e8ed1b8bc42bf017ee9":[10,8,8,6,5],
-"group__spa__json.html#gace48d5f93c0be66297f2389175de2ee0":[10,8,8,6,21],
-"group__spa__json.html#gad27e11f0d644f60840cb42bdcc370412":[10,8,8,6,14],
-"group__spa__json.html#gad655166a86f6b9b79fb480603bf63ec3":[10,8,8,6,18],
-"group__spa__json.html#gae465abe3ff0170d6b630ead5901fba56":[10,8,8,6,11],
-"group__spa__json.html#gae51e8d4cc1999ffcc20802cc9e3f8a97":[10,8,8,6,31],
-"group__spa__json__pod.html":[10,3],
-"group__spa__json__pod.html#ga7904434cb7205e5aa65caa9a7d225e77":[10,3,2],
-"group__spa__json__pod.html#gaffbc97d3a2e34cca3c9735634c2a3013":[10,3,1],
-"group__spa__keys.html":[10,8,8,7],
-"group__spa__keys.html#ga0dace91385a7adfa4181b957c5eb4b22":[10,8,8,7,4],
-"group__spa__keys.html#ga102acfa48ef947978f6dbd43198b40b8":[10,8,8,7,34],
-"group__spa__keys.html#ga14254eeea7166c2132dbaf78286ab1e3":[10,8,8,7,43],
-"group__spa__keys.html#ga1c7eb1e5cc136e4ae2f838b4ef84a705":[10,8,8,7,47],
-"group__spa__keys.html#ga24b3a715c206cc820fd7610668e3f674":[10,8,8,7,37],
-"group__spa__keys.html#ga2a24032ac2675af80e58f291ed8f4010":[10,8,8,7,6],
-"group__spa__keys.html#ga303df0e437c81eecc7be8d7d6d7043fb":[10,8,8,7,24],
-"group__spa__keys.html#ga318114d113c9b8dc802d11bc1b012de9":[10,8,8,7,42],
-"group__spa__keys.html#ga39218bf95ccc444b5284386cf696a84b":[10,8,8,7,52],
-"group__spa__keys.html#ga3922fb11532f928abf055d8b9be5ec03":[10,8,8,7,54]
+"group__spa__json.html#ga9110761cf050dd015410b949edd24350":[10,8,8,6,15]
 };
